@@ -109,12 +109,7 @@ def add_kernel(path, init_kernel):
         
     return w1
     
- def top_bottom_class(train_path, top, other):
-    # - функция определения верхнего класса
-    # train_path - путь к обучающей выборке
-    # top - верхний класс, задается списком
-    # other - нижний класс, задается списком
-    
+def top_bottom_class(train_path, top, other):
     all_classes = pd.read_csv(train_path)
     
 
@@ -484,20 +479,6 @@ def scale_weights_binary(up, down):
     class_top = pd.read_csv('class_top.csv')
     class_others = pd.read_csv('class_others.csv')
 
-    #up = 0
-    #for i in class_top['Scalar_calc']:
-    #    if(i > class_others['Scalar_calc'].max()):
-    #        up+=1
-    #    else:
-    #        break
-        
-    #down = 0
-    #for i in range(len(class_down['Scalar_calc'])-1, 0, -1):
-    #    if(class_down['Scalar_calc'][i] < class_middle['Scalar_calc'].min()):
-    #        down+=1
-    #    else:
-    #        break
-
     other_classes_max = class_others['Scalar_calc'].max()
     
     up = 0
@@ -525,16 +506,13 @@ def scale_weights_binary(up, down):
     d_down = class_others['Scalar_calc'].min()
     d_up = class_top['Scalar_calc'].min()
 
-    mx =  d_up#(d_up + class_down['Scalar_calc'].max())/2
-    mn = d_down#(d_down + class_down['Scalar_calc'].min())/2
+    mx =  d_up
+    mn = d_down
     
     print(up)
     print(down)
-    #mx = (d_up + class_others['Scalar_calc'].max())/2
-    #mn = (d_down + class_d2['Scalar_calc'][down])/2
+
     print()
-    #print(mx)
-    #print(mn)
 
     scaled_weights = [(2*weights_up[0])/(mx - mn),
            (2*weights_up[1])/(mx - mn),
@@ -550,11 +528,9 @@ def scale_weights_binary(up, down):
            (2*weights_up[11])/(mx - mn),
            (2*weights_up[12])/(mx - mn),
            (-2*mn)/(mx - mn)-1]
-    #print()
-    #print(scaled_weights)
 
     f = open('scaled_weights.txt', 'w')
     f.write(str(scaled_weights))
     f.close()
     
-    return scaled_weights
\ No newline at end of file
+    return scaled_weights
